pub fn patch0<R>(target: fn() -> R, func: fn() -> R) -> PatchGuardExpand description
Patch replaces a function with another. Accepts closures as replacement functions as long as they do not bind to the environment.
pub fn patch0<R>(target: fn() -> R, func: fn() -> R) -> PatchGuardPatch replaces a function with another. Accepts closures as replacement functions as long as they do not bind to the environment.