pub fn patch9<R, A, B, C, D, E, F, G, H, I>(
target: fn(A, B, C, D, E, F, G, H, I) -> R,
func: fn(A, B, C, D, E, F, G, H, I) -> R,
) -> PatchGuardExpand description
Patch replaces a function with another. Accepts closures as replacement functions as long as they do not bind to the environment.